#!/usr/bin/env python
'''precision recall'''
import matplotlib
matplotlib.use("agg")
from matplotlib import pylab as plt
import numpy as np

method_list=["MetaGO","structure","sequence","PPIhomo","GoFDR","PSIBLAST","BLAST","Naive"]

linestyle=["-",":",":",":","-","-","-","-"]
linestyle=["-",":","--","--","-","-","-","-"]
marker_list=[
    'o',
    'v',
    '^',
    'D', # PPIhomo
    '<',
    '>',
    's',
    '', # Naive
    '8',
    'p',
    'h',
    'H',
    'D',
    '*',
]

Aspect_list=["MF","BP","CC"]
namespace_dict={'MF':"Molecular Function",'BP':"Biological Process",'CC':"Cellular Component"}

color_list=[
    'k', # MetaGO
    'r', # structure
    'b', # sequence
    'g', # PPIhomo
    'm', # GoFDR
    'c', # PISBLAST
    'y', # BLAST
    '0.5', # Naive
]
#marker_list="ov^<>8sp*hHDd"
lw_list=[
    2, # MetaGO
    1, # structure
    1, # sequence
    1, # PPIhomo
    2, # GoFDR
    2, # PISBLAST
    2, # BLAST
    2, # Naive
]

fig=plt.figure()
fig_subplot,axes = plt.subplots(nrows=2, ncols=2)
fig_subplot.tight_layout()
plt.subplots_adjust(wspace = 2)
for i,Aspect in enumerate(Aspect_list):
    plt.subplot(2,2,i+1)
    for m,method in enumerate(method_list):
        data=np.loadtxt("ROC_%s_%s.csv"%(method,Aspect),
            comments='#')
        plt.plot(data[1:-1,2],data[1:-1,1],
            color_list[m]+marker_list[m],
            lw=lw_list[m], linestyle=linestyle[m],
            markevery=1+len(data[1:-1,2])/5,
            )

    plt.axis([0,1,0,1])
    plt.xlabel("recall")
    plt.ylabel("precision")
    #plt.title(namespace_dict[Aspect])
    plt.title(Aspect)

ax=plt.subplot(2,2,4)
for m,method in enumerate(method_list):
    plt.plot([0.5,0.5],[0.5,0.5],color_list[m], lw=lw_list[m]*1.5,
        linestyle=linestyle[m], marker=marker_list[m],
        label=method,
    )
plt.gca().axes.get_xaxis().set_visible(False)
plt.gca().axes.get_yaxis().set_visible(False)
for border in ["left","right","top","bottom"]:
    ax.spines[border].set_visible(False)
lg=plt.legend(loc="center",fontsize=11,ncol=2,handlelength=3)
lg.draw_frame(False)
plt.plot([0.5,0.5],[0.5,0.5],'wo',lw=0,markersize=10,markeredgecolor='w')

plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
plt.savefig("precison-recall.eps",dpi=500)
plt.savefig("precison-recall.svg",dpi=500)
plt.savefig("precison-recall.png",dpi=400)
plt.close()
