#!/usr/bin/env python
docstring='''make_uniparc_hist.py seqID.list
    make a histogram for the last column of seqID.list
'''
import matplotlib
matplotlib.use("agg")
from matplotlib import pylab as plt
import numpy as np
import sys

if len(sys.argv)!=2:
    sys.stderr.write(docstring)
    exit()

fp=open(sys.argv[1],'rU')
seqID_list=[float(line.split()[2]) for line in fp.read().splitlines()]
fp.close()

bins=np.arange(0,1+0.01,0.01)

fig=plt.figure(
   figsize=(6,4.5)
)
n, bins, patches=plt.hist(seqID_list,bins)
y_max=1.01*n.max()
plt.xlabel("sequence identity to closest function homolog")
plt.ylabel("counts")
plt.plot([0.3,0.3],[0,y_max],'r',lw=2)
plt.plot([0.5,0.5],[0,y_max],'g',lw=2)
plt.axis([0,1,0,y_max])

plt.tight_layout()

for outfmt in ["png","eps","svg"]:
    plt.savefig("1_seqID_hist."+outfmt,dpi=400)

sys.stdout.write("%.2f "%(100.*(sum(
    [seqID>0.5 for seqID in seqID_list]))/len(seqID_list)
    )+'%'+" in (0.5,1]\n")

sys.stdout.write("%.2f "%(100.*(sum(
    [seqID>0.3 and seqID<=0.5 for seqID in seqID_list]))/len(seqID_list)
    )+'%'+" in (0.3,0.5]\n")

sys.stdout.write("%.2f "%(100.*(sum(
    [seqID<=0.3 for seqID in seqID_list]))/len(seqID_list)
    )+'%'+" in (0,0.3]\n")
